@@ -18,28 +18,29 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.33 2004/01/06 23:19:25 gman Exp $
+$Id: properties.c,v 1.36 2004/07/02 18:32:02 cneumair Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <sys/file.h>
-#include <sys/ioctl.h>
-#include <sys/types.h>
-#include <sys/sysctl.h>
 #include <stdio.h>
 
 #ifdef __FreeBSD__
 #include <machine/apm_bios.h>
-#elif __OpenBSD__
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 #include <sys/param.h>
 #include <machine/apmvar.h>
 #elif __linux__
 #include <apm.h>
 #endif
 
+#include <sys/file.h>
+#include <sys/ioctl.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
+
 #include <err.h>
 #include <stdlib.h>
 #include <string.h>
@@ -66,7 +67,7 @@ $Id: properties.c,v 1.33 2004/01/06 23:19:25 gman Exp $
 #define gettext_noop(String) (String)
 #endif
 
-#ifdef __OpenBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
 extern struct apm_power_info apminfo;
 #else
 extern struct apm_info apminfo;
@@ -335,6 +336,7 @@ prop_cb (BonoboUIComponent *uic,
   gboolean   writable;
   GConfClient *client;
   gboolean   inhibit_command_line;
+  AtkObject *atk_widget;
 
   client = gconf_client_get_default ();
   inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
@@ -344,7 +346,7 @@ prop_cb (BonoboUIComponent *uic,
 #ifdef __FreeBSD__
   percentage = apminfo.ai_batt_life;
   if(percentage == 255) percentage = 0;
-#elif __OpenBSD__
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
   percentage = apminfo.battery_life;
   if(percentage == 255) percentage = 0;
 #elif __linux__
@@ -491,9 +493,22 @@ prop_cb (BonoboUIComponent *uic,
   }
 
   battstat->progdir_radio = glade_xml_get_widget (glade_xml, "dir_radio_top");
+  
+  atk_widget = gtk_widget_get_accessible (battstat->progdir_radio);
+  if (GTK_IS_ACCESSIBLE (atk_widget)) {
+	  atk_object_set_name (atk_widget,
+			  _("Progress Bar Direction Moves towards top"));
+  }
+  
   g_signal_connect (G_OBJECT (battstat->progdir_radio), "toggled",
   		    G_CALLBACK (progdir_toggled), battstat);
   widget = glade_xml_get_widget (glade_xml, "dir_radio_bottom");
+  
+  atk_widget = gtk_widget_get_accessible (widget);
+  if (GTK_IS_ACCESSIBLE (atk_widget)) {
+	  atk_object_set_name (atk_widget,
+			  _("Progress Bar Direction Moves towards bottom"));
+  }
 
   if ( ! key_writable (PANEL_APPLET (battstat->applet), "drain_from_top")) {
 	  hard_set_sensitive (battstat->progdir_radio, FALSE);
