@@ -21,8 +21,11 @@ struct _charpick_data {
   gint panel_size;
   gboolean panel_vertical;
   GtkWidget *propwindow;
+  GtkWidget *about_dialog;
   GtkWidget *pref_tree;
   GtkWidget *menu;
+  GtkWidget *add_edit_dialog;
+  GtkWidget *add_edit_entry;
 };
 
 
@@ -36,6 +39,7 @@ struct _charpick_button_cb_data {
 
 
 void start_callback_update();
+void register_stock_for_edit ();
 
 void build_table              (charpick_data     *curr_data);
 void add_to_popup_menu (charpick_data *curr_data);
@@ -44,7 +48,10 @@ void save_chartable (charpick_data *curr_data);
 void show_preferences_dialog  (BonoboUIComponent *uic,
 			       charpick_data     *curr_data,
 			       const char        *verbname);
-gchar *run_edit_dialog  (gchar *string, gchar *title);
+
+void add_edit_dialog_create (charpick_data	 *curr_data,
+			     gchar		 *string,
+			     gchar		 *title);
 void set_atk_name_description (GtkWidget         *widget,
 			       const char        *name,
 			       const char        *description);
