@@ -1226,7 +1226,7 @@ exec_clicked_cmd (GtkWidget *widget, GdkEventButton *event, gpointer data)
 	MailCheck *mc = data;
 	gboolean retval = FALSE;
 
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 
 		if (mc->clicked_enabled && mc->clicked_cmd && (strlen(mc->clicked_cmd) > 0))
 			mailcheck_execute_shell (mc, mc->clicked_cmd);
@@ -1424,7 +1424,15 @@ make_remote_widgets_sensitive(MailCheck *mc)
 	gboolean b = mc->mailbox_type != MAILBOX_LOCAL &&
 	             mc->mailbox_type != MAILBOX_LOCALDIR;
         gboolean f = mc->mailbox_type == MAILBOX_IMAP;
+	gboolean p = mc->mailbox_type == MAILBOX_POP3;
 	
+	soft_set_sensitive (mc->newmail_cmd_check, !p);
+	if (p)
+		soft_set_sensitive (mc->newmail_cmd_entry, !p);
+	else
+		soft_set_sensitive (mc->newmail_cmd_entry, mc->newmail_enabled);
+	soft_set_sensitive (mc->play_sound_check, !p);
+
 	soft_set_sensitive (mc->mailfile_fentry, !b);
 	soft_set_sensitive (mc->mailfile_label, !b);
 	
@@ -1449,7 +1457,7 @@ mail_file_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->mail_file);
+	if (mc->mail_file)
 		g_free (mc->mail_file);
 		
 	mc->mail_file = text;
@@ -1466,7 +1474,7 @@ remote_server_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_server);
+	if (mc->remote_server)
 		g_free (mc->remote_server);
 		
 	mc->remote_server = text;
@@ -1484,7 +1492,7 @@ remote_username_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_username);
+	if (mc->remote_username)
 		g_free (mc->remote_username);
 		
 	mc->remote_username = text;
@@ -1539,7 +1547,7 @@ remote_folder_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_folder);
+	if (mc->remote_folder)
 		g_free (mc->remote_folder);
 		
 	mc->remote_folder = text;
@@ -2143,7 +2151,7 @@ mailcheck_properties_page (MailCheck *mc)
 		hard_set_sensitive (mc->play_sound_check, FALSE);
 
 	/*l = gtk_check_button_new_with_mnemonic (_("Set the number of unread mails to _zero when clicked"));*/
-	l = gtk_check_button_new_with_mnemonic (_("Sto_p animation when double clicked"));
+	l = gtk_check_button_new_with_mnemonic (_("Sto_p animation when clicked"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->reset_on_clicked);
 	g_signal_connect(G_OBJECT(l), "toggled",
 			   G_CALLBACK(reset_on_clicked_toggled), mc);
@@ -2259,7 +2267,7 @@ mailcheck_properties_page (MailCheck *mc)
 		if ( ! key_writable (mc->applet, "newmail_command"))
 			hard_set_sensitive (mc->newmail_cmd_entry, FALSE);
 
-		l = gtk_check_button_new_with_mnemonic (_("When double clicke_d:"));
+		l = gtk_check_button_new_with_mnemonic (_("When clicke_d:"));
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->clicked_enabled);
 		g_signal_connect(G_OBJECT(l), "toggled",
 				 G_CALLBACK(clicked_toggled), mc);
@@ -2480,7 +2488,10 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 				     documenters,
    				     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				     pixbuf);
-				     
+
+	if (pixbuf)
+		g_object_unref (pixbuf);
+
 	gtk_window_set_wmclass (GTK_WINDOW (mc->about), "mailcheck", "Mailcheck");
 
 	gtk_window_set_screen (GTK_WINDOW (mc->about),
