@@ -153,6 +153,7 @@ typedef struct {
 	int 		    mixerchannel;
 	GList		    *channels;
 	gchar		    *device;
+	gint                panel_size;
 
 	GtkAdjustment     *adj;
 
@@ -610,7 +611,7 @@ mixer_value_changed_cb (GtkAdjustment *adj, MixerData *data)
 {
 	gint vol;
 
-	vol = -adj->value;
+	vol = adj->value;
 	
 	data->vol = vol;
 
@@ -751,8 +752,6 @@ mixer_update_slider (MixerData *data)
 {
 	gint vol = data->vol;
 
-	vol = -vol;
-	
 	gtk_adjustment_set_value (data->adj, vol);
 }
 
@@ -781,14 +780,31 @@ mixer_load_volume_images (MixerData *data) {
 					     volume_icon_size, NULL);
 }
 
+static void
+applet_size_allocate (GtkWidget *widget, GtkAllocation *allocation, MixerData *data)
+{
+	if (IS_PANEL_HORIZONTAL (data->orientation)) {
+		if (data->panel_size != allocation->height) {
+			data->panel_size = allocation->height;
+			mixer_update_image (data);
+		}
+	}
+	else {
+		if (data->panel_size != allocation->width) {
+			data->panel_size = allocation->width;
+			mixer_update_image (data);
+		}
+	}
+			
+}
+
+
 static void
 mixer_update_image (MixerData *data)
 {
 	gint vol, size;
 	GdkPixbuf *pixbuf, *copy, *scaled = NULL;
 	vol = data->vol;
-
-	size = panel_applet_get_size (PANEL_APPLET (data->applet));
 	
 	if (vol <= 0)
 		pixbuf = gdk_pixbuf_copy (data->zero);
@@ -817,7 +833,7 @@ mixer_update_image (MixerData *data)
 		g_object_unref (mute);
 	}
 
-	size = MAX (11, size);
+	size = MAX (11, data->panel_size);
 	scaled = gdk_pixbuf_scale_simple (pixbuf, size, size, GDK_INTERP_BILINEAR);
 	gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), scaled);
 	g_object_unref (scaled);	
@@ -1034,12 +1050,12 @@ mixer_popup_show (MixerData *data)
 	if (IS_PANEL_HORIZONTAL (data->orientation)) {
 		box = gtk_vbox_new (FALSE, 0);
 		data->scale = gtk_vscale_new (data->adj);
-		gtk_widget_set_size_request (data->scale, -1, 100);			
+		gtk_widget_set_size_request (data->scale, -1, 100);
+		gtk_range_set_inverted (GTK_RANGE (data->scale), TRUE);
 	} else {
 		box = gtk_hbox_new (FALSE, 0);
 		data->scale = gtk_hscale_new (data->adj);
 		gtk_widget_set_size_request (data->scale, 100, -1);
-		gtk_range_set_inverted (GTK_RANGE (data->scale), TRUE);
 	}
 	
 	if (gail_loaded) {
@@ -1234,6 +1250,8 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		gtk_widget_destroy (data->error_dialog);
 	if (data->tooltips)
 		g_object_unref (data->tooltips);
+	if (data->device)
+		g_free (data->device);
 	g_free (data);
 }
 
@@ -1892,9 +1910,9 @@ mixer_applet_create (PanelApplet *applet)
 			  data);
 	
 	data->adj = GTK_ADJUSTMENT (
-		gtk_adjustment_new (-50,
-				    -VOLUME_MAX,
-				    0.0, 
+		gtk_adjustment_new (50,
+				    0.0,
+				    VOLUME_MAX, 
 				    VOLUME_MAX/20,
 				    VOLUME_MAX/10,
 				    0.0));
@@ -1937,6 +1955,11 @@ mixer_applet_create (PanelApplet *applet)
 			  G_CALLBACK (applet_change_background_cb),
 			  data);
 
+	g_signal_connect (applet,
+			  "size_allocate",
+			  G_CALLBACK (applet_size_allocate),
+			  data);
+
 	panel_applet_setup_menu_from_file (applet, 
 					   NULL, /* opt_datadir */
 					   "GNOME_MixerApplet.xml",
