@@ -23,19 +23,27 @@
 #include <stickynotes_callbacks.h>
 #include <util.h>
 
+static void response_cb (GtkWidget *dialog, gint id, gpointer data);
+
 /* Create a new (empty) Sticky Note */
-StickyNote * stickynote_new()
+StickyNote * stickynote_new(GdkScreen *screen)
 {
 	/* Create Sticky Note instance */
 	StickyNote *note = g_new(StickyNote, 1);
+	GtkIconSize size;
 	
 	/* Create and initialize a Sticky Note */
 	note->window = glade_xml_new(GLADE_PATH, "stickynote_window", NULL);
 	note->menu = glade_xml_new(GLADE_PATH, "stickynote_menu", NULL);
 	note->properties = glade_xml_new(GLADE_PATH, "stickynote_properties", NULL);
 	note->w_window = glade_xml_get_widget(note->window, "stickynote_window");
+	gtk_window_set_screen(GTK_WINDOW(note->w_window),screen);
+
 	note->w_menu = glade_xml_get_widget(note->menu, "stickynote_menu");
+
 	note->w_properties = glade_xml_get_widget(note->properties, "stickynote_properties");
+	gtk_window_set_screen(GTK_WINDOW(note->w_properties),screen);
+
 	note->w_entry = glade_xml_get_widget(note->properties, "title_entry");
 	note->w_color = glade_xml_get_widget(note->properties, "note_color");
 	note->w_font = glade_xml_get_widget(note->properties, "note_font");
@@ -47,12 +55,13 @@ StickyNote * stickynote_new()
 	note->w_close = glade_xml_get_widget(note->window, "close_button");
 	note->w_resize_se = glade_xml_get_widget(note->window, "resize_se_box");
 	note->w_resize_sw = glade_xml_get_widget(note->window, "resize_sw_box");
+
 	note->color = NULL;
 	note->font = NULL;
 	note->locked = FALSE;
 	note->visible = FALSE;
-	note->x = 0;
-	note->y = 0;
+	note->x = -1;
+	note->y = -1;
 	note->w = 0;
 	note->h = 0;
 
@@ -64,9 +73,13 @@ StickyNote * stickynote_new()
 						      gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL));
 
 	/* Set the button images */
-	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "close_img")), STICKYNOTES_STOCK_CLOSE, STICKYNOTES_ICON_SIZE);
-	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "resize_se_img")), STICKYNOTES_STOCK_RESIZE_SE, STICKYNOTES_ICON_SIZE);
-	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "resize_sw_img")), STICKYNOTES_STOCK_RESIZE_SW, STICKYNOTES_ICON_SIZE);
+	size = gtk_icon_size_from_name ("stickynotes_icon_size");
+	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "close_img")), STICKYNOTES_STOCK_CLOSE, size);
+	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "resize_se_img")), STICKYNOTES_STOCK_RESIZE_SE, size);
+	gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "resize_sw_img")), STICKYNOTES_STOCK_RESIZE_SW, size);
+	gtk_widget_show(note->w_lock);
+	gtk_widget_show(note->w_close);
+	gtk_widget_show(glade_xml_get_widget(note->window, "resize_bar"));
 	
 	/* Customize the title and colors, hide and unlock */
 	stickynote_set_title(note, NULL);
@@ -84,7 +97,9 @@ StickyNote * stickynote_new()
 
 	/* Connect a properties dialog to the note */
 	gtk_window_set_transient_for(GTK_WINDOW(note->w_properties), GTK_WINDOW(note->w_window));
-	
+	gtk_dialog_set_default_response(GTK_DIALOG(note->w_properties), GTK_RESPONSE_CLOSE);
+	g_signal_connect (G_OBJECT (note->w_properties), "response", G_CALLBACK (response_cb), note);
+
 	/* Connect signals to the sticky note */
 
 	g_signal_connect(G_OBJECT(note->w_lock), "clicked", G_CALLBACK(stickynote_toggle_lock_cb), note);
@@ -96,10 +111,6 @@ StickyNote * stickynote_new()
 	g_signal_connect(G_OBJECT(note->w_window), "expose-event", G_CALLBACK(stickynote_expose_cb), note);
 	g_signal_connect(G_OBJECT(note->w_window), "configure-event", G_CALLBACK(stickynote_configure_cb), note);
 	g_signal_connect(G_OBJECT(note->w_window), "delete-event", G_CALLBACK(stickynote_delete_cb), note);
-	g_signal_connect(G_OBJECT(note->w_window), "enter-notify-event", G_CALLBACK(stickynote_cross_cb), note);
-	g_signal_connect(G_OBJECT(note->w_window), "leave-notify-event", G_CALLBACK(stickynote_cross_cb), note);
-	g_signal_connect(G_OBJECT(note->w_window), "focus-in-event", G_CALLBACK(stickynote_focus_cb), note);
-	g_signal_connect(G_OBJECT(note->w_window), "focus-out-event", G_CALLBACK(stickynote_focus_cb), note);
 	
 	g_signal_connect(G_OBJECT(glade_xml_get_widget(note->menu, "popup_create")), "activate", G_CALLBACK(popup_create_cb), note);
 	g_signal_connect(G_OBJECT(glade_xml_get_widget(note->menu, "popup_destroy")), "activate", G_CALLBACK(popup_destroy_cb), note);
@@ -112,7 +123,10 @@ StickyNote * stickynote_new()
 	g_signal_connect(G_OBJECT(note->w_font), "font_set", G_CALLBACK(properties_font_cb), note);
 	g_signal_connect_swapped(G_OBJECT(note->w_def_font), "toggled", G_CALLBACK(properties_apply_font_cb), note);
 	g_signal_connect(G_OBJECT(note->w_entry), "activate", G_CALLBACK(properties_activate_cb), note);
-	g_signal_connect(G_OBJECT(note->w_properties), "response", G_CALLBACK(properties_response_cb), note);
+	
+	gtk_widget_show_all (note->w_window);
+	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(note->w_window), TRUE);
+	gtk_window_set_skip_pager_hint(GTK_WINDOW(note->w_window), TRUE);
 	
 	return note;
 }
@@ -150,11 +164,20 @@ void stickynote_change_properties(StickyNote *note)
 	if (note->font)
 		gnome_font_picker_set_font_name(GNOME_FONT_PICKER(note->w_font), note->font);
 
-	gtk_dialog_run(GTK_DIALOG(note->w_properties));
+	gtk_widget_show (note->w_properties);
 
 	stickynotes_save();
 }
 
+static void
+response_cb (GtkWidget *dialog, gint id, gpointer data)
+{
+        if (id == GTK_RESPONSE_HELP)
+                gnome_help_display ("stickynotes_applet", "stickynotes-introduction", NULL);
+        else
+                gtk_widget_hide (dialog);
+}
+
 /* Check if a sticky note is empty */
 gboolean stickynote_get_empty(const StickyNote *note)
 {
@@ -167,17 +190,15 @@ void stickynote_set_title(StickyNote *note, const gchar *title)
 	/* If title is NULL, use the current date as the title. */
 	if (!title) {
 		gchar *date_format = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/settings/date_format", NULL);
+		if (!date_format)
+			date_format = g_strdup ("%x");
 		title = get_current_date(date_format);
 		g_free(date_format);
 	}
 		
 	gtk_window_set_title(GTK_WINDOW(note->w_window), title);
-
-	{
-		gchar *bold_title = g_strdup_printf("<b>%s</b>", title);
-		gtk_label_set_markup(GTK_LABEL(note->w_title), bold_title);
-		g_free(bold_title);
-	}
+	gtk_label_set_text (GTK_LABEL (note->w_title), title);
+	
 }
 
 /* Set the sticky note color */
@@ -299,19 +320,24 @@ void stickynote_set_font(StickyNote *note, const gchar *font_str, gboolean save)
 /* Lock/Unlock a sticky note from editing */
 void stickynote_set_locked(StickyNote *note, gboolean locked)
 {
+	GtkIconSize size;
 	note->locked = locked;
 
 	/* Set cursor visibility and editability */
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(note->w_body), !locked);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(note->w_body), !locked);
 
+	size = gtk_icon_size_from_name ("stickynotes_icon_size");
+	
 	/* Show appropriate icon and tooltip */
 	if (locked) {
-		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")), STICKYNOTES_STOCK_LOCK, STICKYNOTES_ICON_SIZE);
+		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")),
+					 STICKYNOTES_STOCK_LOCKED, size);
 		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("Locked note"), NULL);
 	}
 	else {
-		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")), STICKYNOTES_STOCK_UNLOCK, STICKYNOTES_ICON_SIZE);
+		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")),
+					 STICKYNOTES_STOCK_UNLOCKED, size);
 		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("Unlocked note"), NULL);
 	}
 
@@ -328,7 +354,8 @@ void stickynote_set_visible(StickyNote *note, gboolean visible)
 	if (visible) {
 		/* Show & raise sticky note, then move to the corrected location on screen. */
 		gtk_window_present(GTK_WINDOW(note->w_window));
-		gtk_window_move(GTK_WINDOW(note->w_window), note->x, note->y);
+		if (note->x != -1 || note->y != -1)
+			gtk_window_move(GTK_WINDOW(note->w_window), note->x, note->y);
 	}
 	else {
 		/* Hide sticky note */
@@ -337,9 +364,9 @@ void stickynote_set_visible(StickyNote *note, gboolean visible)
 }
 
 /* Add a sticky note */
-void stickynotes_add()
+void stickynotes_add(GdkScreen *screen)
 {
-	StickyNote *note = stickynote_new();
+	StickyNote *note = stickynote_new(screen);
 
 	/* Add the note to the linked-list of all notes */
 	stickynotes->notes = g_list_append(stickynotes->notes, note);
@@ -352,7 +379,10 @@ void stickynotes_add()
 
 	/* Show all sticky notes */
 	stickynote_set_visible(note, TRUE);
-	gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", TRUE, NULL);
+
+	/* Only set the visible flag if we can actually write it */
+	if (gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL))
+		gconf_client_set_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", TRUE, NULL);
 }
 
 /* Remove a sticky note with confirmation, if needed */
@@ -363,9 +393,9 @@ void stickynotes_remove(StickyNote *note)
 
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(note->w_window));
 
-	if (stickynote_get_empty(note) ||
-	    !gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/confirm_deletion", NULL) ||
-	    gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
+	if (stickynote_get_empty(note)
+	    || !gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/confirm_deletion", NULL)
+	    || gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
 		stickynote_free(note);
 
 		/* Remove the note from the linked-list of all notes */
@@ -458,12 +488,12 @@ void stickynotes_save()
 }
 
 /* Load all sticky notes from an XML configuration file */
-void stickynotes_load()
+void stickynotes_load(GdkScreen *screen)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root;
 	xmlNodePtr node;
-	
+
 	/* The XML file is $HOME/.gnome2/stickynotes_applet, most probably */
 	{
 		gchar *file = g_strdup_printf("%s%s", g_get_home_dir(), XML_PATH);
@@ -491,7 +521,7 @@ void stickynotes_load()
 	while (node) {
 		if (!xmlStrcmp(node->name, (const xmlChar *) "note")) {
 			/* Create a new note */
-			StickyNote *note = stickynote_new();
+			StickyNote *note = stickynote_new(screen);
 			stickynotes->notes = g_list_append(stickynotes->notes, note);
 
 			/* Retrieve and set title of the note */
@@ -533,11 +563,14 @@ void stickynotes_load()
 			{
 				gchar *x_str = xmlGetProp(node, "x");
 				gchar *y_str = xmlGetProp(node, "y");
-				if (x_str && y_str)
-					gtk_window_move(GTK_WINDOW(note->w_window), atoi(x_str), atoi(y_str));
-				gtk_window_get_position(GTK_WINDOW(note->w_window), &note->x, &note->y);
-				g_free(x_str);
-				g_free(y_str);
+				if (x_str && y_str) {
+					if (atoi(x_str) != -1 || atoi(y_str) !=-1) {
+					    gtk_window_move(GTK_WINDOW(note->w_window), atoi(x_str), atoi(y_str));
+					}
+					gtk_window_get_position(GTK_WINDOW(note->w_window), &note->x, &note->y);
+					g_free(x_str);
+					g_free(y_str);
+				}
 			}
 
 			/* Retrieve and set (if any) the body contents of the note */
