@@ -50,15 +50,15 @@ static gboolean stickynotes_applet_factory(PanelApplet *panel_applet, const gcha
 {
 	if (!strcmp(iid, "OAFIID:GNOME_StickyNotesApplet")) {
 		if (!stickynotes)
-			stickynotes_applet_init(panel_applet);
+			stickynotes_applet_init (panel_applet);
 			
 		panel_applet_set_flags (panel_applet, PANEL_APPLET_EXPAND_MINOR);
 
 		/* Add applet to linked list of all applets */
-		stickynotes->applets = g_list_append(stickynotes->applets, stickynotes_applet_new(panel_applet));
+		stickynotes->applets = g_list_append (stickynotes->applets, stickynotes_applet_new(panel_applet));
 
-		stickynotes_applet_update_menus();
-		stickynotes_applet_update_tooltips();
+		stickynotes_applet_update_menus ();
+		stickynotes_applet_update_tooltips ();
 
 		return TRUE;
 	}
@@ -116,6 +116,7 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 {	
 	GnomeIconTheme *icon_theme;
 	gchar *sticky_icon;
+	GnomeClient *client;
 
 	stickynotes = g_new(StickyNotes, 1);
 
@@ -124,6 +125,9 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 
 	icon_theme = gnome_icon_theme_new ();
 	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme, "stock_notes", 48, NULL, NULL);
+	/* Register size for icons */
+	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
+	
 
 	if (sticky_icon) {
 		gnome_window_icon_set_default_from_file(sticky_icon);
@@ -148,9 +152,16 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 	gconf_client_add_dir(stickynotes->gconf, GCONF_PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/defaults", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/settings", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
+
+	client = gnome_master_client ();
+	gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
+
+	/* The help suggests this is automatic, but that seems to not be the case here. */
+	gnome_client_connect (client);
+	gnome_client_flush (client);
 	
 	/* Load sticky notes */
-	stickynotes_load();
+	stickynotes_load(gtk_widget_get_screen(GTK_WIDGET(panel_applet)));
 	
 	/* Auto-save every so minutes (default 5) */
 	g_timeout_add(1000 * 60 * gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/autosave_time", NULL),
@@ -263,6 +274,7 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->w_applet = GTK_WIDGET(panel_applet);
 	applet->w_image = gtk_image_new();
 	applet->about_dialog = NULL;
+	applet->destroy_all_dialog = NULL;
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
@@ -337,18 +349,30 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 
 void stickynotes_applet_update_prefs()
 {
-	gint width = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL);
-	gint height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
-	gboolean sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
-	gboolean sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
-	gint click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
-	gboolean sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
-	gboolean force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
-	gchar *font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
-	
+	gint height, click_behavior;
+	gboolean sys_color, sys_font, sticky, force_default;
+	gchar *font_str;
 	GdkColor color;
+	gint width = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL);
+
+	width = MAX (width, 1);
+	height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
+	height = MAX (height, 1);
+
+	sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
+	sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
+	click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
+	sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
+	force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
+	font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
+
+	if (!font_str)
+		font_str = g_strdup ("Sans 10");
+	
 	{
 		gchar *color_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL);
+		if (!color_str)
+			color_str = g_strdup ("#FFFF00");
 		gdk_color_parse(color_str, &color);
 		g_free(color_str);
 	}
@@ -420,7 +444,7 @@ void stickynotes_applet_update_tooltips()
 	g_free(tooltip);
 }
 
-void stickynotes_applet_do_default_action()
+void stickynotes_applet_do_default_action(GdkScreen *screen)
 {
 	StickyNotesDefaultAction click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
 
@@ -429,7 +453,7 @@ void stickynotes_applet_do_default_action()
 
 	switch (click_behavior) {
 		case STICKYNOTES_NEW:
-			stickynotes_add();
+			stickynotes_add(screen);
 			break;
 
 		case STICKYNOTES_SET_VISIBLE:
